aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/cpp/thread_manager/thread_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/cpp/thread_manager/thread_manager.h')
-rw-r--r--src/cpp/thread_manager/thread_manager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/cpp/thread_manager/thread_manager.h b/src/cpp/thread_manager/thread_manager.h
index 1113031695..5a40f2de47 100644
--- a/src/cpp/thread_manager/thread_manager.h
+++ b/src/cpp/thread_manager/thread_manager.h
@@ -23,10 +23,11 @@
#include <list>
#include <memory>
#include <mutex>
-#include <thread>
#include <grpcpp/support/config.h>
+#include "src/core/lib/gprpp/thd.h"
+
namespace grpc {
class ThreadManager {
@@ -84,8 +85,8 @@ class ThreadManager {
virtual void Wait();
private:
// Helper wrapper class around std::thread. This takes a ThreadManager object
// and starts a new std::thread to calls the Run() function.
//
// The Run() function calls ThreadManager::MainWorkLoop() function and once
// that completes, it marks the WorkerThread completed by calling
@@ -101,8 +102,7 @@ class ThreadManager {
void Run();
ThreadManager* const thd_mgr_;
- std::mutex wt_mu_;
- std::thread thd_;
+ grpc_core::Thread thd_;
};
// The main funtion in ThreadManager
@@ -84,8 +85,8 @@ class ThreadManager {
virtual void Wait();
private:
- // Helper wrapper class around std::thread. This takes a ThreadManager object
- // and starts a new std::thread to calls the Run() function.
+ // Helper wrapper class around grpc_core::Thread. Takes a ThreadManager object
+ // and starts a new grpc_core::Thread to calls the Run() function.
//
// The Run() function calls ThreadManager::MainWorkLoop() function and once